% Simulates data from the Calvo Plus model with:
%
% 1. Constant aggregate demand
% 2. I.i.d. normal growth of the price level (non-zero mean)
% 3. AR(1)-normal idiosyncratic marginal cost shocks
%
% Inputs:
%   InflSim: Simulated series for monthly inflation
%   InflSim_sum: Simulated series for the nominal price level
%   NSim: Number of time periods to be simulated
%   burnin: Number of time periods at the start of the simulation that are
%      dropped
%   a: Grid for a (idiosyncratic marginal cost shock)
%   rp: Grid for the real price
%   rho: Autoregressive coefficient in process for a_t
%   sigma_eps: Standard deviation of shocks to a_t process
%   mu: Average monthly inflation rate
%   sigma_eta: Standard deviation of shocks to the price level
%   F: The policy function
%   tfunc: If tfunc == 1 then the function prints out the time it takes to run
%   yesprint: If yesprint == 1 then the function prints 'progress reports'
%
% Outputs:
%   aSim: Simulated series for a (idiosyncratic marginal cost shock)
%   rpSim: Simulated series for the real price
%   npSim: Simulated series for the nominal price
%   ncostSim: Simulated series for log(P_t)+ log(A_it)

%
% Notice: If this function starts printing out 'x' or 'y' it means that
% the grid for rp does not cover a large enough area.
%
% Jon Steinsson and Emi Nakamura, May 2006
%
% Adjusted by Mikael Carlsson, June 2013
%**************************************************************
function [aSim,rpSim,npSim,ncostSim] ...
    = DataSim_Calvo_Plus(InflSim, InflSim_sum,InflSim_num,NSim,burnin,a,rp,mu_mc,rho,eps_a,F_high,F_low, Calvo_draw)

amax = a(end,1);
amin = a(1,1);
agridsize = size(a,1);

rpmax = rp(end,1);
rpmin = rp(1,1);
rpgridsize = size(rp,1);
Infl_inc = (rpmax-rpmin)/(rpgridsize-1);

% Simulate a time series for a
%**************************************************************

aSim = zeros(NSim+burnin+1,1);
a_inc = (amax-amin)/(agridsize-1);
aSim(1,1) = a((agridsize/2 - mod(agridsize/2,1) + 1),1);
for i = 1:(NSim+burnin)
    delta_a = mu_mc + (rho-1)*aSim(i,1) + eps_a(i,1);
    delta_a_mod = mod(delta_a,a_inc);
    delta_a_mod_big = a_inc/2 < delta_a_mod;
    delta_a_mod_small = a_inc/2 >= delta_a_mod;
    delta_a_grid = delta_a - delta_a_mod_small*delta_a_mod ...
        + delta_a_mod_big*(a_inc-delta_a_mod);
    aSim(i+1,1) = aSim(i,1) + delta_a_grid;
    aSim(i+1,1) = min(amax,aSim(i+1,1));
    aSim(i+1,1) = max(amin,aSim(i+1,1));
end
aSim_num = int32((aSim - amin*ones(NSim+burnin+1,1))/a_inc+1);


% Simulate a time series for rp
%**************************************************************

rpSim = zeros(NSim+burnin+1,1);
rpSim_num = zeros(NSim+burnin+1,1);
rp_inc = (rpmax-rpmin)/(rpgridsize-1);
rpSim(1,1) = rp((rpgridsize/2 - mod(rpgridsize/2,1) + 1),1);
rpSim_num(1,1) = (rpSim(1,1) - rpmin)/rp_inc+1;
for i = 1:(NSim+burnin)
    % Adjust for inflation
    pre_adj_rp_num = rpSim_num(i,1) - double(InflSim_num(i+1,1));
    if pre_adj_rp_num > rpgridsize
        cutoff = mod(pre_adj_rp_num,rpgridsize);
        pre_adj_rp_num = rpgridsize;
        InflSim(i+1,1) = InflSim(i+1,1) - cutoff*Infl_inc;
        InflSim_num(i+1,1) = InflSim_num(i+1,1) - cutoff;
        fprintf('x ')
    end
    if pre_adj_rp_num < 1
        addon = 1-pre_adj_rp_num;
        pre_adj_rp_num = 1;
        InflSim(i+1,1) = InflSim(i+1,1) + addon*Infl_inc;
        InflSim_num(i+1,1) = InflSim_num(i+1,1) + addon;
        fprintf('y ')
    end
    
    % Calculate new price
    rpSim(i+1,1) = (Calvo_draw(i,1)==1)*F_high(int32(pre_adj_rp_num),int32(aSim_num(i+1,1)))...
                  +(Calvo_draw(i,1)==0)*F_low(int32(pre_adj_rp_num),int32(aSim_num(i+1,1)));
    rpSim_num(i+1,1) = int32((rpSim(i+1,1) - rpmin)/rp_inc+1);
end

% Create Nominal Series
%**************************************************************

npSim = zeros(NSim+burnin+1,1);
ncostSim = zeros(NSim+burnin+1,1);
npSim(1,1) = rp((rpgridsize/2 - mod(rpgridsize/2,1) + 1),1);
ncostSim(1,1) = a((agridsize/2 - mod(agridsize/2,1) + 1),1);
npSim(2:end,1) = rpSim(2:end,1) + InflSim_sum(2:end,1);
ncostSim(2:end,1) = aSim(2:end,1) + InflSim_sum(2:end,1);

aSim = aSim((burnin+2):end,1);
rpSim = rpSim((burnin+2):end,1);
npSim = npSim((burnin+2):end,1);
ncostSim = ncostSim((burnin+2):end,1);

