% Value Function Iteration for a Calvo Plus model with:
%
% 1. Constant aggregate demand
% 2. I.i.d. normal growth of the price level (non-zero mean)
% 3. AR(1)-normal idiosyncratic marginal cost shocks
%
%
% Outputs:
%    rV: The real valued value function
%    F: The policy function (log price)
%
% Mikael Carlsson, June 2013
%
% Based on original menu cost code by 
% Jon Steinsson and Emi Nakamura, May 2006
%
%********************************************************

function [rV,F_high,F_low] = VFIteration_CalvoPlus(rPi,ErV,beta,K_high, K_low,alpha_Calvo,rp,Proba,ProbInfl,...
    tolerance,yesprint)

rpgridsize = size(ProbInfl,1);
agridsize = size(Proba,1);

time1 = cputime;
i = 1;
ErV_new = ErV;

Vsubopt = 4*tolerance;
while Vsubopt/2 > tolerance
    ErV_old = ErV_new;
    % Expected value if nominal price is not changed
    ErV_notchange = rPi + beta*ErV_old;
    
    % Expected value if nominal price is changed at high cost
    ErV_change_high = ones(rpgridsize,1)*max(rPi-K_high+beta*ErV_old);
    % Compare the two and choose the higher
    ErV_compare_high = zeros(2,rpgridsize,agridsize);
    ErV_compare_high(1,:,:) = ErV_notchange; 
    ErV_compare_high(2,:,:) = ErV_change_high;
    ErV_new_high = squeeze(max(ErV_compare_high));
    % Take expectations
    ErV_high = ProbInfl*ErV_new_high*Proba';
    
    % Expected value if nominal price is changed at low cost
    ErV_change_low = ones(rpgridsize,1)*max(rPi-K_low+beta*ErV_old);
    % Compare the two and choose the higher
    ErV_compare_low = zeros(2,rpgridsize,agridsize);
    ErV_compare_low(1,:,:) = ErV_notchange; 
    ErV_compare_low(2,:,:) = ErV_change_low;
    ErV_new_low = squeeze(max(ErV_compare_low));
    % Take expectations
    ErV_low = ProbInfl*ErV_new_low*Proba';

    % Take weighted average 
    ErV_new = alpha_Calvo*ErV_high + (1-alpha_Calvo)*ErV_low;
        
    Vdifmax = max(max(ErV_new - ErV_old));
    Vdifmin = min(min(ErV_new - ErV_old));
    Vsubopt = Vdifmax-Vdifmin;

    if yesprint == 1
        if mod(i,5) == 0
            fprintf('.')
        end
        if mod(i,400) == 0
            fprintf('\n')
        end
    end
    i = i + 1;    
end

ErV = ErV_new;

fprintf('\n\n')
fprintf('Time to convergence: %8.3f\n\n',cputime - time1)

% No Change
rV_notchange = rPi + beta*ErV;

% High Cost
[rV_change_high rp_change_high] = max(rPi-K_high+beta*ErV);
rV_change_high = ones(rpgridsize,1)*rV_change_high;
rV_dif_high = rV_change_high - rV_notchange;

F_change_high = (rV_dif_high>0);
F_notchange_high = (F_change_high==0);
F_high = F_notchange_high.*(rp*ones(1,agridsize))+F_change_high.*(ones(rpgridsize,1)*rp(rp_change_high,1)');

% Low Cost
[rV_change_low rp_change_low] = max(rPi-K_low+beta*ErV);
rV_change_low = ones(rpgridsize,1)*rV_change_low;
rV_dif_low = rV_change_low - rV_notchange;

F_change_low = (rV_dif_low>0);
F_notchange_low = (F_change_low==0);
F_low = F_notchange_low.*(rp*ones(1,agridsize))+F_change_low.*(ones(rpgridsize,1)*rp(rp_change_low,1)');

% Combine
rV = alpha_Calvo*(F_notchange_high.*rV_notchange + F_change_high.*rV_change_high)+...
     (1-alpha_Calvo)*(F_notchange_low.*rV_notchange + F_change_low.*rV_change_low);




