% *****************************************************************
% Solves a simple partial equilibrium menu cost model by Bellman  
% function iteration on a grid. Then use this solution and simulate  
% a panel of firms for use in the Monte Carlo experiment in
% Carlsson (2017)
%
% Mikael Carlsson, January 2017 
%
% This code use large parts of code written by  
% Jon Steinsson and Emi Nakamura available at 
% http://www.columbia.edu/~js3204/papers/MenuCostModelCode.zip
%******************************************************************

clear all;
clc
parpool local

% Set Parameters
%**************************************************************

C = 1;                  % Aggregate demand - Normalized
theta = 3;             
beta = 0.96^(1/12);     

K = 0.079068741070278;   
    
% Parameters of the idiosyncratic marginal cost process (log A_it)
% log(A_it) = rho*log(A_it-1) + eps_it
% where eps_it ~ N(0,sigma_eps^2), i.i.d. 
% The process is truncated at +/- trunc_eps multiples of the unconditional 
% standard deviation of log(A) 

rho = 0.921078195906405;       
sigma_eps = 0.067556048274351; 

% Constant for real marginal cost process 

mu_mc = (1-rho)*log((theta-1)/theta);

trunc_eps = 4;

% Parameters of the process followed by the inflation rate (log(P_t/P_t-1))
% log(P_t) - log(P_t-1) = mu + nu_t
% where nu_t ~ N(0,sigma_eta^2), i.i.d.

% Here - Price level shock is turned off - only drift

mu =0.00138; 

sigma_eta =0;

inflationrate = (1+mu)^12-1;

% Number of points on the grid for the two state variables
agridsize = 1000;
rpgridsize = 1200;


% Max and Min point for the grid of "a"
amax = trunc_eps*(sigma_eps^2/(1-rho^2))^(1/2) + log((theta-1)/theta);
amin = -trunc_eps*(sigma_eps^2/(1-rho^2))^(1/2) + log((theta-1)/theta);


% % The rp grid is a grid for the log of the real price
rpmax = 1.2*(amax + log(theta/(theta-1)));
rpmin = 1.2*(amin + log(theta/(theta-1)));

K_adj = K*(theta/(theta-1));

fprintf('\n')
fprintf('Inflation Rate: %3.1f percent \n',inflationrate*100)
fprintf('mu:             %5.4f \n',mu)
fprintf('sigma_eta:      %5.4f \n',sigma_eta)
fprintf('rho:            %5.4f \n',rho)
fprintf('sigma_eps:      %5.4f \n',sigma_eps)
fprintf('C:              %5.4f \n',C)
fprintf('theta:          %5.4f \n',theta)
fprintf('beta:           %5.4f \n',beta)
fprintf('K:              %5.4f \n\n',K_adj)
fprintf('amax = %5.4f   amin = %5.4f\n',amax,amin)
fprintf('rpmax = %5.4f  rpmin = %5.4f\n',rpmax,rpmin)
fprintf('\n')

% Create the real price and idiosyncratic marginal-cost vectors
% (in logs)
%**************************************************************

a = amin:((amax-amin)/(agridsize-1)):amax; a = a';
rp = rpmin:((rpmax-rpmin)/(rpgridsize-1)):rpmax; rp = rp';

% Create Probability Distribution for the idiosyncratic shock
%**************************************************************
% Proba is a matrix that gives transition probabilities of going
% from state a to state a', i.e. Proba(i,j) = Prob(a' = j | a = i)
% 
% The procedure of Tauchen (1986) is used to approximate the 
% AR(1) process for log(A_it)

% Laplace Shocks - inside prob_dist_a
Proba = prob_dist_a(mu_mc, rho,sigma_eps,a);

% Create Probability Distribution for movements in the real price
% due to inflation
%**************************************************************
% ProbInfl is a matrix that gives the transition probabilities of 
% the real price due to inflation when the nominal price is fixed
%
% ProbInfl gives the probabilities of going from state rp to state 
% rp', i.e. ProbInfl(i,j) = Prob(pr' = j | pr = i)
% 
% The exact distribution is approximated using a 
% method analogous to the Tauchen (1986) method for AR models

ProbInfl = prob_dist_infl(mu,sigma_eta,rp);

% Calculate Profit function matrix
%**************************************************************
% Prices vary as one moves down each column
% Marginal cost varies as one moves across each row

rPi = C*(exp(rp).^(-theta+1)*ones(1,agridsize)...
    -exp(rp).^(-theta)*exp(a'));


% Bellman function iteration
%**************************************************************
% Here we iterate ErV
% Initialize
ErV = zeros(rpgridsize,agridsize);
tolerance = 10^(-8);

fprintf('Start Iterating on Value Function')
[rV,F] = VFIteration(rPi,ErV,beta,K,rp,Proba,ProbInfl,...
    tolerance,1);

% Simulate n panel data sets from the model, i.e. 
% all firms face the same inflation outcome in a panel 
%**************************************************************

% Initialize 
NPanels = 200;
NFirms  = 3510;
NSim    = 12*5;
burnin  = 200;
NFirms_by_NSim_annual = NFirms*NSim/12;
% Draw NPanels inflation outcomes 
RandStream.setGlobalStream(RandStream('mt19937ar','seed',197211));

PDS_Infl_arr = zeros(NSim+burnin+1,NPanels,3);

fprintf('\n')
fprintf('Simulating Inflation')
fprintf('\n')


% Simulate NPanels time series for Infl moving between gridpoints
%****************************************************************

Infl_inc = (rpmax-rpmin)/(rpgridsize-1);
for j = 1:NPanels
    nu = sigma_eta*randn(NSim+burnin,1);
    nu = [0; nu];
    InflSim = mu + nu;
    InflSim_mod = mod(InflSim,Infl_inc);
    InflSim_mod_big = Infl_inc/2 < InflSim_mod;
    InflSim_mod_small = Infl_inc/2 >= InflSim_mod;
    InflSim = InflSim - InflSim_mod_small.*InflSim_mod ...
        + InflSim_mod_big.*(Infl_inc-InflSim_mod);
    InflSim_num = int32(InflSim/Infl_inc);
    InflSim_sum = zeros(NSim+burnin+1,1);
    for i = 1:(NSim+burnin)
        InflSim_sum(i+1,1) = InflSim_sum(i,1) + InflSim(i+1,1);
    end
    PDS_Infl_arr(:,j,1) = InflSim(:,1);
    PDS_Infl_arr(:,j,2) = InflSim_sum(:,1);
    PDS_Infl_arr(:,j,3) = InflSim_num(:,1);
end

% Simulate NFirms time series for 
% each panel moving between gridpoints 
%**************************************************************

fprintf('\n')
fprintf('Simulating Firm Data')
fprintf('\n')


PDS_firm_arr = zeros(NSim,NFirms,NPanels,6);

%PDS_firm_arr(,,,1) = rpSim;
%PDS_firm_arr(,,,2) = aSim;
%PDS_firm_arr(,,,3) = npSim;
%PDS_firm_arr(,,,4) = ncostSim;

% Laplace Shocks
eps_a_temp = laprnd_array(NSim+burnin,NFirms,NPanels,0, sigma_eps);
 
siz = [NSim,NFirms,1,6];
parfor j = 1:NPanels
    eps_a = eps_a_temp(:,:,j);
    Pfat = zeros(siz);
    for l = 1:NFirms
        [Pfat(:,l,1,2),Pfat(:,l,1,1),Pfat(:,l,1,3),Pfat(:,l,1,4)] ...
            = DataSim(PDS_Infl_arr(:,j,1), PDS_Infl_arr(:,j,2), PDS_Infl_arr(:,j,3),NSim,burnin,a,rp,mu_mc,rho,eps_a(:,l),F);
        % Log Demand/Production
        Pfat(:,l,1,5) = log(C*(exp(Pfat(:,l,1,1)).^(-theta)));            
    end;
    PDS_firm_arr(:,:,j,:) = Pfat;
end;

fprintf('\n')
fprintf('Done')
fprintf('\n')
fprintf('\n')

% Max and Min Simulated rp and a
rp_vector = reshape(PDS_firm_arr(:,:,:,1),NFirms*NSim*NPanels,1);
max_rp_vector = max(rp_vector);
min_rp_vector = min(rp_vector);


a_vector = reshape(PDS_firm_arr(:,:,:,2),NFirms*NSim*NPanels,1);
max_a_vector = max(a_vector);
min_a_vector = min(a_vector);


fprintf('amax simulation = %5.4f   amin simulation = %5.4f\n',max_a_vector,min_a_vector)
fprintf('rpmax simulation = %5.4f  rpmin simulation = %5.4f\n',max_rp_vector,min_rp_vector)
fprintf('\n')
fprintf('\n')
fprintf('percentiles [0.05, 0.1, 0.25, 50, 99.75, 99.9, 99.95]')
fprintf('\n')
p = [0.05, 0.1, 0.25, 50, 99.75, 99.9, 99.95]; 
fprintf('a simulation')
percentiles_a = prctile(a_vector,p);
fprintf('\n')
fprintf('rp simulation')
percentiles_rp = prctile(rp_vector,p);
fprintf('\n')
fprintf('\n')

av_markup = mean(exp(PDS_firm_arr(:,1,1,3))./exp(PDS_firm_arr(:,1,1,4)));
fprintf('Average Markup for Simulated Firm: %5.4f \n',av_markup);

% Historgram of Monthly Price and Marginal Cost Changes
%**************************************************************
PDS_firm_arr_monthly_diff_data = zeros(NSim,NFirms,NPanels,2);

% PDS_firm_arr_monthly_diff_data(,,,1) log diff of nominal price
% PDS_firm_arr_monthly_diff_data(,,,2) log diff of nominal marginal cost

for j = 1:NPanels
    for l = 1:NFirms
        for k = 2:NSim
            % log price change
            PDS_firm_arr_monthly_diff_data(k,l,j,1) = PDS_firm_arr(k,l,j,3) - PDS_firm_arr(k-1,l,j,3);
            % log marginal cost change
            PDS_firm_arr_monthly_diff_data(k,l,j,2) = PDS_firm_arr(k,l,j,4) - PDS_firm_arr(k-1,l,j,4);
        end
    end
    PDS_firm_arr_monthly_diff_data(1,:,j,1) = NaN;
    PDS_firm_arr_monthly_diff_data(1,:,j,2) = NaN;
end

d_log_price_monthly = reshape(PDS_firm_arr_monthly_diff_data(:,:,:,1),NFirms*NSim*NPanels,1); 
d_log_price_monthly = d_log_price_monthly(~isnan(d_log_price_monthly));



spike_monthly = (abs(d_log_price_monthly)<=0.005);
spike_share_monthly = sum(spike_monthly)/length(spike_monthly);
fprintf('\n')
fprintf('Monthly share +/- 0.5 percent: %3.3f \n',spike_share_monthly)
fprintf('\n')

d_log_marginal_cost_monthly = reshape(PDS_firm_arr_monthly_diff_data(:,:,:,2),NFirms*NSim*NPanels,1); 
d_log_marginal_cost_monthly =d_log_marginal_cost_monthly(~isnan(d_log_marginal_cost_monthly));

scale= -0.5:0.01:0.5;
bins = hist(d_log_price_monthly, scale);
bins = 100*(bins/length(d_log_price_monthly));

bins2 = hist(d_log_marginal_cost_monthly, scale);
bins2 = 100*(bins2/length(d_log_marginal_cost_monthly));

figure(3)
subplot(1,2,1)
bar(scale,bins,0.99)
set(gca,'xlim',[-.6 .6])
set(gca,'ylim',[0 15.2])
xlabel('Monthly Log Price Change')
ylabel('Percent');
subplot(1,2,2)
bar(scale,bins2,0.99)
set(gca,'xlim',[-.6 .6])
set(gca,'ylim',[0 15.2])
xlabel('Monthly Log Marginal Cost Change')
ylabel('Percent');

% Data for histograms in STATA
fprintf('Saving Data for Monthly Histograms')
fprintf('\n\n')
data = [d_log_price_monthly(1:100000,1) d_log_marginal_cost_monthly(1:100000,1)];
dlmwrite('C:\sim_data\MCM_sim_dat_monthly_hist.raw', data);
fprintf('Done')
fprintf('\n\n')

% Average Real Profit (Gross of Adjustment Cost)
% **************************************************************
% PDS_firm_arr(,,,1) = rpSim;
% PDS_firm_arr(,,,2) = aSim;
% PDS_firm_arr(,,,3) = npSim;
% PDS_firm_arr(,,,4) = ncostSim;

real_gross_profit_array = C*(exp(PDS_firm_arr(:,:,:,1)).^(-theta)).*(exp(PDS_firm_arr(:,:,:,1))-exp(PDS_firm_arr(:,:,:,2)));

real_gross_profit = reshape(real_gross_profit_array(:,:,:),NFirms*NSim*NPanels,1);

kappa_share_in_r_g_p = K/mean(real_gross_profit); 
fprintf('Share of Kappa((Theta-1)/Theta) in Real Gross Profits: %5.4f \n',kappa_share_in_r_g_p);
fprintf('\n')

% Annual Price and Cost Series (weighted as in real data)
%**************************************************************
NSim_years = NSim/12;
PDS_firm_arr_annual = zeros(NSim_years,NFirms,NPanels,7);

for j = 1:NPanels
    for l = 1:NFirms
        for k = 1:NSim_years
            i = k*12;
            y_sum = sum(exp(PDS_firm_arr(i-11:i,l,j,5)));
            PDS_firm_arr(i-11:i,l,j,6) = exp(PDS_firm_arr(i-11:i,l,j,5))./y_sum;
            % Annual Weighted Series
            % Log price 
            PDS_firm_arr_annual(k,l,j,1) = log(sum(exp(PDS_firm_arr(i-11:i,l,j,3)).*PDS_firm_arr(i-11:i,l,j,6)));
            % Log marginal cost
            PDS_firm_arr_annual(k,l,j,3) = log(sum(exp(PDS_firm_arr(i-11:i,l,j,4)).*PDS_firm_arr(i-11:i,l,j,6)));
            % Log real marginal cost
            PDS_firm_arr_annual(k,l,j,5) = log(sum(exp(PDS_firm_arr(i-11:i,l,j,2)).*PDS_firm_arr(i-11:i,l,j,6)));
        end
    end
end

for j = 1:NPanels
    for l = 1:NFirms
        for k = 2:NSim_years
            % log price change
            PDS_firm_arr_annual(k,l,j,2) = PDS_firm_arr_annual(k,l,j,1) - PDS_firm_arr_annual(k-1,l,j,1);
            % log marginal cost change
            PDS_firm_arr_annual(k,l,j,4) = PDS_firm_arr_annual(k,l,j,3) - PDS_firm_arr_annual(k-1,l,j,3);
            % log real marginal cost change
            PDS_firm_arr_annual(k,l,j,6) = PDS_firm_arr_annual(k,l,j,5) - PDS_firm_arr_annual(k-1,l,j,5);
            % lag log real marginal cost
            PDS_firm_arr_annual(k,l,j,7) = PDS_firm_arr_annual(k-1,l,j,5);
        end
    end
    PDS_firm_arr_annual(1,:,j,2) = NaN;
    PDS_firm_arr_annual(1,:,j,4) = NaN;
    PDS_firm_arr_annual(1,:,j,6) = NaN;
    PDS_firm_arr_annual(1,:,j,7) = NaN;
end

% Compare to calibration targets - Stack up all firms in all  
% panels for this exercise
%**************************************************************

% Persistence of Real Marginal Cost Shock
log_r_marginal_cost = reshape(PDS_firm_arr_annual(:,:,:,5),NFirms_by_NSim_annual*NPanels,1);
l_log_r_marginal_cost = reshape(PDS_firm_arr_annual(:,:,:,7),NFirms_by_NSim_annual*NPanels,1);

const_term = ones(NFirms_by_NSim_annual*NPanels,1);
X = [const_term, l_log_r_marginal_cost];
[b] = regress(log_r_marginal_cost,X);

fprintf('\n')
fprintf('Moments Match')
fprintf('\n')
fprintf('Annual rho: Target = 0.542 / Model = %3.3f \n',b(2,1))

% Standard Deviation of Real Marginal Cost Change
d_log_r_marginal_cost = reshape(PDS_firm_arr_annual(:,:,:,6),NFirms_by_NSim_annual*NPanels,1); 
d_log_r_marginal_cost = d_log_r_marginal_cost(~isnan(d_log_r_marginal_cost));
s = std(d_log_r_marginal_cost);

fprintf('Annual s.d. real mc change: Target = 0.145 / Model = %3.3f \n',s)

% Zero Nominal Price Change Spike
d_log_price = reshape(PDS_firm_arr_annual(:,:,:,2),NFirms_by_NSim_annual*NPanels,1); 
d_log_price = d_log_price(~isnan(d_log_price));
spike = (abs(d_log_price)<=0.005);
spike_share = sum(spike)/length(spike);
fprintf('Annual share +/- 0.5 percent: Target = 0.136 / Model = %3.3f \n',spike_share)
fprintf('\n')

% Historgram of Annual Price and Marginal Cost Changes
%**************************************************************
scale= -1:0.01:1;
bins = hist(d_log_price, scale);
bins = 100*(bins/length(d_log_price));

d_log_marginal_cost = reshape(PDS_firm_arr_annual(:,:,:,4),NFirms_by_NSim_annual*NPanels,1); 
d_log_marginal_cost = d_log_marginal_cost(~isnan(d_log_marginal_cost));

bins2 = hist(d_log_marginal_cost, scale);
bins2 = 100*(bins2/length(d_log_price));

figure(4)
subplot(1,2,1)
bar(scale,bins,0.99)
set(gca,'xlim',[-1.1 1.1])
set(gca,'ylim',[0 15.2])
xlabel('Log price change')
ylabel('Percent');
subplot(1,2,2)
bar(scale,bins2,0.99)
set(gca,'xlim',[-1.1 1.1])
set(gca,'ylim',[0 15.2])
xlabel('Log marginal cost change')
ylabel('Percent');

% Data to STATA - One file for each panel
%**************************************************************
h = waitbar(0,'Saving Simulated Data Sets For STATA - Please Wait...');
for j = 1:NPanels
    data  = zeros(NFirms_by_NSim_annual,4);
    % Generate Panel ID
    for i = 1:NFirms
        k = i*NSim_years;
        data(k-NSim_years+1:k,1) = i*ones(NSim_years,1);
    end
    % Generate Time
    time = (1:1:NSim_years)';
    data(:,2)  = repmat(time,NFirms,1);
    % Log Price
    data(:,3) = reshape(PDS_firm_arr_annual(:,:,j,1),NFirms_by_NSim_annual,1);
    % Log Marginal Cost
    data(:,4) = reshape(PDS_firm_arr_annual(:,:,j,3),NFirms_by_NSim_annual,1);
    % Save the data in ASCII-delimited file
    strnum      = int2str(j);
    strpath     = 'C:\sim_data\MCM_sim_dat_';
    strformat   = '.raw';
    str_int     = [strpath,strnum,strformat];
    dlmwrite(str_int, data)
    waitbar(j / NPanels)
end
close(h)

% Data for histograms in STATA
%**************************************************************
fprintf('Saving Data for Histograms')
fprintf('\n\n')
data = [d_log_price d_log_marginal_cost];
dlmwrite('C:\sim_data\MCM_sim_dat_hist.raw', data);

% End
delete(gcp('nocreate'))


