***************************************************************
* FILE:		Stat_Code.do
* PACKAGE:	Stata 14.2 MP                                              
* PURPOSE:	Stata Code for Carlsson (2017)
* BY:		Mikael Carlsson                                                          
***************************************************************

set more off, permanently
clear all 
capture log close
log using C:\results\State_Dependence, replace

***************************************************************
* Observed Data
***************************************************************

* Same data set as in Carlsson and Nordström Skans (2012) AER
use C:\data\estimation_base.dta, clear

xtset plant_good_marker aar
sort plant_good_marker aar


* Transformations for probability regressions
gen  d_ln_price_9d  =  ln_price_9d - l.ln_price_9d

gen  d_ln_obs_marginal_cost_is = ln_obs_marginal_cost_is - l.ln_obs_marginal_cost_is
gen  abs_d_ln_obs_marginal_cost_is = abs(d_ln_obs_marginal_cost_is)

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.005 & d_ln_price_9d ~= .
tab ind_price_changer
summarize d_ln_price_9d, detail

** Regression

reg ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

gen l_abs_d_ln_obs_marginal_cost_is = l.abs_d_ln_obs_marginal_cost_is

reg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

* Time Dummies
xi i.aar
reg ind_price_changer abs_d_ln_obs_marginal_cost_is _I*, cluster(cfarnr)

reg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is _I*, cluster(cfarnr)

* Firm Fixed Effects
xtreg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, fe i(cfarnr) cluster(cfarnr)

* Time Dummies + Firm Fixed Effects
xtreg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is _I*, fe i(cfarnr) cluster(cfarnr)

* Probit
dprobit ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
 
* Logit
logit ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is) atmeans


histogram d_ln_price_9d if d_ln_price_9d >=  -0.995, start(-0.995)  width(0.01) percent xtitle(Log price change) /*
*/ xlabel(-1 -0.5 0 0.5 1) name(Hist_price_changes_data, replace) scheme(s2mono)


histogram d_ln_price_9d if d_ln_price_9d >=  -0.495 & d_ln_price_9d <=0.505, start(-0.495)  width(0.01) percent xtitle(Log price change - Data) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_price_changes_main, replace) scheme(s2mono)


* Marginal cost stats - for Calibration of Menu Cost Model 
***************************************************************
* Same Data as in Carlsson and Nordström Skans (2012) AER
use C:\data\estimation_base.dta, clear

xtset plant_good_marker aar
sort plant_good_marker aar

gen  d_ln_price_9d  =  ln_price_9d - l.ln_price_9d
gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.005 & d_ln_price_9d ~= .
tab ind_price_changer
gen temp = 1-ind_price_changer
mean temp, vce(cluster cfarnr)

keep  aar cfarnr ln_obs_marginal_cost_is   
duplicates drop 
xtset  cfarnr aar
xtdes

sort cfarnr aar
gen d_ln_obs_marginal_cost_is  = d.ln_obs_marginal_cost_is  
xtsum d_ln_obs_marginal_cost_is

* Idiosyncratic variation - Take out time dummies

* Bootstrap Routine 
program define stdev_bs, rclass
	reg d_ln_obs_marginal_cost_is i.aar
	predict d_ln_obs_marginal_cost_is_id, residuals 
	summarize d_ln_obs_marginal_cost_is_id
	return scalar stdev=r(sd)
	drop d_ln_obs_marginal_cost_is_id
end 

tsset, clear
bootstrap stdev_bs=r(stdev), cluster(cfarnr) reps(1000) seed(7211): stdev_bs
estat bootstrap, all

program drop stdev_bs


histogram d_ln_obs_marginal_cost_is if d_ln_obs_marginal_cost_is >=  -0.995, start(-0.995)  width(0.01) percent xtitle(Log unit labor cost change) /*
*/ xlabel(-1 -0.5 0 0.5 1) name(Hist_ulc_changes_data, replace) scheme(s2mono)


histogram d_ln_obs_marginal_cost_is if d_ln_obs_marginal_cost_is >=  -0.495 & d_ln_obs_marginal_cost_is <=0.505, start(-0.495)  width(0.01) percent xtitle(Log unit labor cost change - Data) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_ulc_changes_main, replace) scheme(s2mono)

* Histograms From Data
graph set ps logo off
graph combine Hist_price_changes_data Hist_ulc_changes_data, scheme(s2mono) ycommon xcommon name(Histograms_all, replace)
graph save Histograms_all "C:\results\histograms_data.gph", replace
graph export "C:\results\histograms_data.ps", replace


***************************************************************
* Simulated Data - Menu Cost Model
***************************************************************
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
	qui: gen  abs_d_ln_marginal_cost_sim = abs(d_ln_marginal_cost_sim) 

	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	qui: gen l_abs_d_ln_marginal_cost_sim = l.abs_d_ln_marginal_cost_sim
	
	* Main
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	
	* Lag
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
 	qui: mat est_ols_lag = e(b)
	qui: mat results[`i',2] = est_ols_lag[1,1]
	qui: mat results[`i',3] = est_ols_lag[1,2]

	* Time Dummies
	qui: xi i.aar
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim _I*
	qui: mat est_ols_time = e(b)
	qui: mat results[`i',4] = est_ols_time[1,1]
	qui: mat results[`i',5] = est_ols_time[1,2]
	
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',6] = est_prob_margin[1,1]
	qui: mat results[`i',7] = est_prob_margin[1,2]
	
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: margins, dydx(abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',8] = est_logit_margin[1,1]
	qui: mat results[`i',9] = est_logit_margin[1,2]
	 
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates.dta", replace

* Histograms from simulation 

infile d_log_price d_log_marginal_cost using /*
*/ "C:\sim_data\MCM_sim_dat_hist.raw", clear 

summarize d_log_price d_log_marginal_cost, detail

histogram d_log_price if d_log_price >=  -0.495 & d_log_price <=0.505, start(-0.495)  width(0.01) percent xtitle(Log price change - Simulation) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_price_changes_main_sim, replace) scheme(s2mono)

histogram d_log_marginal_cost if d_log_marginal_cost >=  -0.495 & d_log_marginal_cost <=0.505, start(-0.495)  width(0.01) percent xtitle(Log marginal cost change - Simulation) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_mc_changes_main_sim, replace) scheme(s2mono)

graph set ps logo off
graph combine Hist_price_changes_main Hist_ulc_changes_main Hist_price_changes_main_sim Hist_mc_changes_main_sim, scheme(s2mono) ycommon xcommon name(Histograms_all, replace)
graph save Histograms_all "C:\results\histograms_all.gph", replace
graph export "C:\results\histograms_all.ps", replace

* Histograms from monthly simulation 
infile d_log_price_monthly d_log_marginal_cost_monthly using /*
*/ "C:\sim_data\MCM_sim_dat_monthly_hist.raw", clear 

gen ind_price_changer = 0 if d_log_price_monthly ~= .
replace ind_price_changer = 1 if abs(d_log_price_monthly)>0.005 & d_log_price_monthly ~= .
tab ind_price_changer

* Plot price change distribution without the spike 
twoway__histogram_gen d_log_price_monthly if d_log_price_monthly >=  -0.495 & d_log_price_monthly <=0.505, start(-0.495) width(0.01) percent gen(h x) 

twoway bar h x if x>=  -0.495 & d_log_price_monthly <=0.505 & abs(x)>0.005, barwidth(0.01) bstyle(histogram) xtitle(Log price change - Monthly Simulation) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5)  name(Hist_price_changes_main_sim_m, replace) scheme(s2mono)  
drop h x

histogram d_log_marginal_cost_monthly if d_log_marginal_cost_monthly >=  -0.495 & d_log_marginal_cost_monthly <=0.505, start(-0.495)  width(0.01) percent xtitle(Log marginal cost change - Monthly Simulation) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_mc_changes_main_sim_m, replace) scheme(s2mono)

graph set ps logo off
graph combine Hist_price_changes_main_sim_m Hist_mc_changes_main_sim_m, scheme(s2mono) ycommon xcommon name(Histograms_all_monthly, replace)
graph save Histograms_all_monthly "C:\results\histograms_all_monthly.gph", replace
graph export "C:\results\histograms_all_monthly.ps", replace



***************************************************************
* Simulated Data - Calvo Plus Model
***************************************************************
matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_calvo_plus_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
	qui: gen  abs_d_ln_marginal_cost_sim = abs(d_ln_marginal_cost_sim) 

	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	qui: gen l_abs_d_ln_marginal_cost_sim = l.abs_d_ln_marginal_cost_sim
	
	* Main
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	
	* Lag
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
 	qui: mat est_ols_lag = e(b)
	qui: mat results[`i',2] = est_ols_lag[1,1]
	qui: mat results[`i',3] = est_ols_lag[1,2]

	* Time Dummies
	qui: xi i.aar
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim _I*
	qui: mat est_ols_time = e(b)
	qui: mat results[`i',4] = est_ols_time[1,1]
	qui: mat results[`i',5] = est_ols_time[1,2]
	
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',6] = est_prob_margin[1,1]
	qui: mat results[`i',7] = est_prob_margin[1,2]
	
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: margins, dydx(abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',8] = est_logit_margin[1,1]
	qui: mat results[`i',9] = est_logit_margin[1,2]
	 
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_calvo_plus.dta", replace

* Histograms from simulation 

infile d_log_price d_log_marginal_cost using /*
*/ "C:\sim_data\MCM_sim_dat_calvo_plus_hist.raw", clear 

summarize d_log_price d_log_marginal_cost, detail

histogram d_log_price if d_log_price >=  -0.495 & d_log_price <=0.505, start(-0.495)  width(0.01) percent xtitle(Log price change - Simulation Calvo Plus) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_price_changes_main_sim_cp, replace) scheme(s2mono)

histogram d_log_marginal_cost if d_log_marginal_cost >=  -0.495 & d_log_marginal_cost <=0.505, start(-0.495)  width(0.01) percent xtitle(Log marginal cost change - Simulation Calvo Plus) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_mc_changes_main_sim_cp, replace) scheme(s2mono)

* Histograms from monthly simulation 
infile d_log_price_monthly d_log_marginal_cost_monthly using /*
*/ "C:\sim_data\MCM_sim_dat_calvo_plus_monthly_hist.raw", clear 

gen ind_price_changer = 0 if d_log_price_monthly ~= .
replace ind_price_changer = 1 if abs(d_log_price_monthly)>0.005 & d_log_price_monthly ~= .
tab ind_price_changer

* Plot price change distribution without the spike 
twoway__histogram_gen d_log_price_monthly if d_log_price_monthly >=  -0.495 & d_log_price_monthly <=0.505, start(-0.495) width(0.01) percent gen(h x) 

twoway bar h x if x>=  -0.495 & d_log_price_monthly <=0.505 & abs(x)>0.005, barwidth(0.01) bstyle(histogram) xtitle(Log price change - Monthly Simulation Calvo Plus) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5)  name(Hist_price_changes_main_sim_m, replace) scheme(s2mono) 
drop h x

histogram d_log_marginal_cost_monthly if d_log_marginal_cost_monthly >=  -0.495 & d_log_marginal_cost_monthly <=0.505, start(-0.495)  width(0.01) percent xtitle(Log marginal cost change - Monthly Simulation Calvo Plus) /*
*/ xlabel(-0.5 -0.25 0 0.25 0.5) name(Hist_mc_changes_main_sim_m, replace) scheme(s2mono)

graph set ps logo off
graph combine Hist_price_changes_main_sim_m Hist_mc_changes_main_sim_m, scheme(s2mono) ycommon xcommon name(Histograms_all_mon_calvo_plus, replace)
graph save Histograms_all_mon_calvo_plus "C:\results\histograms_all_mon_calvo_plus.gph", replace
graph export "C:\results\histograms_all_mon_calvo_plus.ps", replace

* All histograms - Annual

graph combine Hist_price_changes_main Hist_ulc_changes_main Hist_price_changes_main_sim Hist_mc_changes_main_sim Hist_price_changes_main_sim_cp Hist_mc_changes_main_sim_cp, cols(2) scheme(s2mono) ycommon xcommon name(Histograms_all_mc_calvo_plus, replace)
graph save Histograms_all_mc_calvo_plus "C:\results\Histograms_all_mc_calvo_plus.gph", replace
graph export "C:\results\Histograms_all_mc_calvo_plus.ps", replace

*** True Selection Effects ***
******************************
clear all
* Same data set as in Carlsson and Nordström Skans (2012) AER
use C:\data\estimation_base.dta, clear

xtset plant_good_marker aar
sort plant_good_marker aar

* Transformations for probability regressions
gen  d_ln_price_9d  =  ln_price_9d - l.ln_price_9d

gen  d_ln_obs_marginal_cost_is = ln_obs_marginal_cost_is - l.ln_obs_marginal_cost_is
gen  abs_d_ln_obs_marginal_cost_is = abs(d_ln_obs_marginal_cost_is)

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.005 & d_ln_price_9d ~= .
tab ind_price_changer

gen l_abs_d_ln_obs_marginal_cost_is = l.abs_d_ln_obs_marginal_cost_is

* Main

reg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.0003 & d_ln_price_9d ~= .
tab ind_price_changer

reg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

* Probit
probit ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is) atmeans

* Logit
logit ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is) atmeans

drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0 & d_ln_price_9d ~= .
tab ind_price_changer

reg ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

* Probit
probit ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is) atmeans

* Logit
logit ind_price_changer abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is l_abs_d_ln_obs_marginal_cost_is) atmeans

* Simulated Data Calvo Plus
****************************

matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_calvo_plus_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
	qui: gen  abs_d_ln_marginal_cost_sim = abs(d_ln_marginal_cost_sim) 
	qui: gen  l_abs_d_ln_marginal_cost_sim = l.abs_d_ln_marginal_cost_sim
		
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	qui: egen temp_1 = count(d_ln_price_sim)
	qui: egen temp_2 = total(ind_price_changer)
	qui: gen temp_3 = 1-temp_2/temp_1
	qui: summarize temp_3
	qui: mat mean = r(mean)
	qui: mat results[`i',15] = mean[1,1] 
	qui: drop temp_1 temp_2 temp_3
	qui: sort plant_good_marker aar
		
	* Column 1
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	qui: mat results[`i',2] = est_ols[1,2]
	
	* Column 2
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.0003 & d_ln_price_sim ~= .

	qui: egen temp_1 = count(d_ln_price_sim)
	qui: egen temp_2 = total(ind_price_changer)
	qui: gen temp_3  = 1-temp_2/temp_1
	qui: summarize temp_3
	qui: mat mean = r(mean)
	qui: mat results[`i',16] = mean[1,1] 
	qui: drop temp_1 temp_2 temp_3
	qui: sort plant_good_marker aar
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',3] = est_ols[1,1]
	qui: mat results[`i',4] = est_ols[1,2]

	* Column 3
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',5] = est_prob_margin[1,1]
	qui: mat results[`i',6] = est_prob_margin[1,2]
		
	* Column 4
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: margins, dydx(abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',7] = est_logit_margin[1,1]
	qui: mat results[`i',8] = est_logit_margin[1,2]
	
	* Column 5
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0 & d_ln_price_sim ~= .

	qui: egen temp_1 = count(d_ln_price_sim)
	qui: egen temp_2 = total(ind_price_changer)
	qui: gen temp_3 = 1-temp_2/temp_1
	qui: summarize temp_3
	qui: mat mean = r(mean)
	qui: mat results[`i',17] = mean[1,1] 
	qui: drop temp_1 temp_2 temp_3
	qui: sort plant_good_marker aar
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',9]  = est_ols[1,1]
	qui: mat results[`i',10] = est_ols[1,2]
	
	* Column 6
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',11] = est_prob_margin[1,1]
	qui: mat results[`i',12] = est_prob_margin[1,2]
		
	* Column 7
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: margins, dydx(abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',13] = est_logit_margin[1,1]
	qui: mat results[`i',14] = est_logit_margin[1,2]
	
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_true_selection_calvo_plus.dta", replace

* Simulated Data Menu Cost
**************************

matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
	qui: gen  abs_d_ln_marginal_cost_sim = abs(d_ln_marginal_cost_sim) 
	qui: gen  l_abs_d_ln_marginal_cost_sim = l.abs_d_ln_marginal_cost_sim
		
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	qui: egen temp_1 = count(d_ln_price_sim)
	qui: egen temp_2 = total(ind_price_changer)
	qui: gen temp_3 = 1-temp_2/temp_1
	qui: summarize temp_3
	qui: mat mean = r(mean)
	qui: mat results[`i',15] = mean[1,1] 
	qui: drop temp_1 temp_2 temp_3
	qui: sort plant_good_marker aar
	
	* Column 1
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	qui: mat results[`i',2] = est_ols[1,2]
	
	* Column 2
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.0003 & d_ln_price_sim ~= .

	qui: egen temp_1 = count(d_ln_price_sim)
	qui: egen temp_2 = total(ind_price_changer)
	qui: gen temp_3  = 1-temp_2/temp_1
	qui: summarize temp_3
	qui: mat mean = r(mean)
	qui: mat results[`i',16] = mean[1,1] 
	qui: drop temp_1 temp_2 temp_3
	qui: sort plant_good_marker aar
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',3] = est_ols[1,1]
	qui: mat results[`i',4] = est_ols[1,2]

	* Column 3
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',5] = est_prob_margin[1,1]
	qui: mat results[`i',6] = est_prob_margin[1,2]
		
	* Column 4
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: margins, dydx(abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',7] = est_logit_margin[1,1]
	qui: mat results[`i',8] = est_logit_margin[1,2]
	
	* Column 5
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0 & d_ln_price_sim ~= .

	qui: egen temp_1 = count(d_ln_price_sim)
	qui: egen temp_2 = total(ind_price_changer)
	qui: gen temp_3 = 1-temp_2/temp_1
	qui: summarize temp_3
	qui: mat mean = r(mean)
	qui: mat results[`i',17] = mean[1,1] 
	qui: drop temp_1 temp_2 temp_3
	qui: sort plant_good_marker aar
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',9]  = est_ols[1,1]
	qui: mat results[`i',10] = est_ols[1,2]
	
	* Column 6
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',11] = est_prob_margin[1,1]
	qui: mat results[`i',12] = est_prob_margin[1,2]
		
	* Column 7
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim
	qui: margins, dydx(abs_d_ln_marginal_cost_sim l_abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',13] = est_logit_margin[1,1]
	qui: mat results[`i',14] = est_logit_margin[1,2]	
	 
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_true_selection_menu_cost.dta", replace
clear  

* Only Contemporraneous Effects
*******************************
 
clear all
* Same data set as in Carlsson and Nordström Skans (2012) AER
use C:\data\estimation_base.dta, clear

xtset plant_good_marker aar
sort plant_good_marker aar

* Transformations for probability regressions
gen  d_ln_price_9d  =  ln_price_9d - l.ln_price_9d

gen  d_ln_obs_marginal_cost_is = ln_obs_marginal_cost_is - l.ln_obs_marginal_cost_is
gen  abs_d_ln_obs_marginal_cost_is = abs(d_ln_obs_marginal_cost_is)

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.005 & d_ln_price_9d ~= .
tab ind_price_changer

gen l_abs_d_ln_obs_marginal_cost_is = l.abs_d_ln_obs_marginal_cost_is

* Main

reg ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.0003 & d_ln_price_9d ~= .
tab ind_price_changer

reg ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

* Probit
probit ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is) atmeans

* Logit
logit ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is) atmeans

drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0 & d_ln_price_9d ~= .
tab ind_price_changer

reg ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)

* Probit
probit ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is) atmeans

* Logit
logit ind_price_changer abs_d_ln_obs_marginal_cost_is, cluster(cfarnr)
margins, dydx(abs_d_ln_obs_marginal_cost_is) atmeans

* Simulated Data Calvo Plus
***************************

matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_calvo_plus_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
	qui: gen  abs_d_ln_marginal_cost_sim = abs(d_ln_marginal_cost_sim) 
			
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
		
	* Column 1
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	
	* Column 2
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.0003 & d_ln_price_sim ~= .
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',2] = est_ols[1,1]


	* Column 3
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',3] = est_prob_margin[1,1]
		
	* Column 4
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim 
	qui: margins, dydx(abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',4] = est_logit_margin[1,1]
	
	* Column 5
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0 & d_ln_price_sim ~= .
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',5]  = est_ols[1,1]
	
	* Column 6
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',6] = est_prob_margin[1,1]

		
	* Column 7
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim 
	qui: margins, dydx(abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',7] = est_logit_margin[1,1]

	
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_true_selection_calvo_plus_con.dta", replace

* Simulated Data Menu Cost
**************************

matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
	qui: gen  abs_d_ln_marginal_cost_sim = abs(d_ln_marginal_cost_sim) 
			
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	* Column 1
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	
	* Column 2
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.0003 & d_ln_price_sim ~= .
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',2] = est_ols[1,1]


	* Column 3
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',3] = est_prob_margin[1,1]
		
	* Column 4
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim 
	qui: margins, dydx(abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',4] = est_logit_margin[1,1]
	
	* Column 5
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0 & d_ln_price_sim ~= .
	
	qui: reg ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_ols = e(b)
	qui: mat results[`i',5]  = est_ols[1,1]
	
	* Column 6
	* Probit
	qui: dprobit ind_price_changer abs_d_ln_marginal_cost_sim
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',6] = est_prob_margin[1,1]

		
	* Column 7
	* Logit 
	qui: logit ind_price_changer abs_d_ln_marginal_cost_sim 
	qui: margins, dydx(abs_d_ln_marginal_cost_sim) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',7] = est_logit_margin[1,1]

	
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_true_selection_menu_cost_con.dta", replace
clear  


********************************
* Alternative Representations 
********************************

**** Kernel Regressions **** 
clear all
* Same data set as in Carlsson and Nordström Skans (2012) AER
use C:\data\estimation_base.dta, clear

xtset plant_good_marker aar
sort plant_good_marker aar

* Transformations for probability regressions
gen  d_ln_price_9d  =  ln_price_9d - l.ln_price_9d

gen  d_ln_obs_marginal_cost_is = ln_obs_marginal_cost_is - l.ln_obs_marginal_cost_is
gen  abs_d_ln_obs_marginal_cost_is = abs(d_ln_obs_marginal_cost_is)

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.005 & d_ln_price_9d ~= .

summarize  abs_d_ln_obs_marginal_cost_is, det

lpoly ind_price_changer abs_d_ln_obs_marginal_cost_is if abs_d_ln_obs_marginal_cost_is<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(0(0.1)0.3) xtick(0(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Abs. Log Unit Labor Cost Change)  n(12)  /*
*/ name(smoother_abs_change_base, replace) title("") nolegend note("") scheme(s2mono)

lpoly ind_price_changer d_ln_obs_marginal_cost_is if abs_d_ln_obs_marginal_cost_is<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(-0.3(0.1)0.3) xtick(-0.3(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Log Unit Labor Cost Change)  n(24)  /*
*/ name(smoother_change_base, replace) title("") nolegend note("") scheme(s2mono)
 
drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0 & d_ln_price_9d ~= .
tab ind_price_changer

lpoly ind_price_changer abs_d_ln_obs_marginal_cost_is if abs_d_ln_obs_marginal_cost_is<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(0(0.1)0.3) xtick(0(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Abs. Log Unit Labor Cost Change - Zero Bin)  n(12)  /*
*/ name(smoother_abs_change_zero, replace) title("") nolegend note("") scheme(s2mono)

lpoly ind_price_changer d_ln_obs_marginal_cost_is if abs_d_ln_obs_marginal_cost_is<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(-0.3(0.1)0.3) xtick(-0.3(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Log Unit Labor Cost Change  - Zero Bin)  n(24)  /*
*/ name(smoother_change_zero, replace) title("") nolegend note("") scheme(s2mono)

graph set ps logo off
graph combine smoother_abs_change_base smoother_change_base smoother_abs_change_zero smoother_change_zero, cols(2)  ycommon name(smoother_fig_rob_2)
graph save smoother_fig_rob_2 "C:\results\smoother_fig_rob_2.gph", replace
graph export "C:\results\smoother_fig_rob_2.ps", replace

graph drop smoother_abs_change_base smoother_change_base smoother_abs_change_zero smoother_change_zero

**** Cumulated Sum of MC Changes *****
clear all
* Same data set as in Carlsson and Nordström Skans (2012) AER
use C:\data\estimation_base.dta, clear

xtset plant_good_marker aar
sort plant_good_marker aar

* Transformations for probability regressions
gen  d_ln_price_9d  =  ln_price_9d - l.ln_price_9d

gen  d_ln_obs_marginal_cost_is = ln_obs_marginal_cost_is - l.ln_obs_marginal_cost_is

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.005 & d_ln_price_9d ~= .

gen accum_mc_change = .
replace accum_mc_change = d_ln_obs_marginal_cost_is if ind_price_changer[_n-1] == 1 & plant_good_marker == plant_good_marker[_n-1] & ind_price_changer ~= . 

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] /*
*/     if ind_price_changer[_n-1] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & plant_good_marker == plant_good_marker[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4] + d_ln_obs_marginal_cost_is[_n-5]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & ind_price_changer[_n-5] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & plant_good_marker == plant_good_marker[_n-6] & ind_price_changer[_n-6] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4] + d_ln_obs_marginal_cost_is[_n-5] + d_ln_obs_marginal_cost_is[_n-6]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & ind_price_changer[_n-5] == 0 & ind_price_changer[_n-6] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & plant_good_marker == plant_good_marker[_n-6] & plant_good_marker == plant_good_marker[_n-7] & ind_price_changer[_n-7] == 1 &  ind_price_changer ~= .

* No more than 5 zeros in a row

gen abs_accum_mc_change = abs(accum_mc_change) 

summarize ind_price_changer abs_accum_mc_change accum_mc_change
summarize ind_price_changer abs_accum_mc_change accum_mc_change if abs_accum_mc_change~=.

** Main regression

reg ind_price_changer abs_accum_mc_change, cluster(cfarnr)

summarize abs_accum_mc_change, det

lpoly ind_price_changer abs_accum_mc_change if abs_accum_mc_change<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(0(0.1)0.3) xtick(0(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Abs. Acc. Log Unit Labor Cost Change - Data)  n(12)  /*
*/ name(smoother_abs_accum_change_base, replace) title("") nolegend note("") scheme(s2mono)

lpoly ind_price_changer abs_accum_mc_change if abs_accum_mc_change<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(0(0.1)0.3) xtick(0(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Abs. Acc. Log Unit Labor Cost Change)  n(12)  /*
*/ name(smoother_abs_accum_change_base_2, replace) title("") nolegend note("") scheme(s2mono)

lpoly ind_price_changer accum_mc_change if abs_accum_mc_change<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(-0.3(0.1)0.3) xtick(-0.3(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Acc. Log Unit Labor Cost Change)  n(24)  /*
*/ name(smoother_accum_change_base, replace) title("") nolegend note("")  scheme(s2mono)

* Time Dummies
xi i.aar
reg ind_price_changer abs_accum_mc_change _I*, cluster(cfarnr)


* Firm Fixed Effects
xtreg ind_price_changer abs_accum_mc_change, fe i(cfarnr) cluster(cfarnr)

* Time Dummies + Firm Fixed Effects
xtreg ind_price_changer abs_accum_mc_change _I*, fe i(cfarnr) cluster(cfarnr)


* Probit
dprobit ind_price_changer abs_accum_mc_change, cluster(cfarnr)

* Logit
logit ind_price_changer abs_accum_mc_change, cluster(cfarnr)
margins, dydx(abs_accum_mc_change) atmeans


*** Shrinking the Band ***
tab ind_price_changer

reg ind_price_changer abs_accum_mc_change, cluster(cfarnr)

drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0.0003 & d_ln_price_9d ~= .
tab ind_price_changer

replace accum_mc_change = .
replace accum_mc_change = d_ln_obs_marginal_cost_is if ind_price_changer[_n-1] == 1 & plant_good_marker == plant_good_marker[_n-1] & ind_price_changer ~= . 

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] /*
*/     if ind_price_changer[_n-1] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & plant_good_marker == plant_good_marker[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4] + d_ln_obs_marginal_cost_is[_n-5]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & ind_price_changer[_n-5] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & plant_good_marker == plant_good_marker[_n-6] & ind_price_changer[_n-6] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4] + d_ln_obs_marginal_cost_is[_n-5] + d_ln_obs_marginal_cost_is[_n-6]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & ind_price_changer[_n-5] == 0 & ind_price_changer[_n-6] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & plant_good_marker == plant_good_marker[_n-6] & plant_good_marker == plant_good_marker[_n-7] & ind_price_changer[_n-7] == 1 &  ind_price_changer ~= .

replace abs_accum_mc_change = abs(accum_mc_change) 

reg ind_price_changer abs_accum_mc_change, cluster(cfarnr)

drop ind_price_changer

gen ind_price_changer = 0 if d_ln_price_9d ~= .
replace ind_price_changer = 1 if abs(d_ln_price_9d)>0 & d_ln_price_9d ~= .
tab ind_price_changer

replace accum_mc_change = .
replace accum_mc_change = d_ln_obs_marginal_cost_is if ind_price_changer[_n-1] == 1 & cfarnr == cfarnr[_n-1] & ind_price_changer ~= . 

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] /*
*/     if ind_price_changer[_n-1] == 0 & cfarnr == cfarnr[_n-1] & cfarnr == cfarnr[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & cfarnr == cfarnr[_n-1] & cfarnr == cfarnr[_n-2] & cfarnr == cfarnr[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & cfarnr == cfarnr[_n-1]  & cfarnr == cfarnr[_n-2] /*
*/     & cfarnr == cfarnr[_n-3] & cfarnr == cfarnr[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & cfarnr == cfarnr[_n-1]  & cfarnr == cfarnr[_n-2] /*
*/     & cfarnr == cfarnr[_n-3] & cfarnr == cfarnr[_n-4] & cfarnr == cfarnr[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4] + d_ln_obs_marginal_cost_is[_n-5]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & ind_price_changer[_n-5] == 0 & cfarnr == cfarnr[_n-1]  & cfarnr == cfarnr[_n-2] /*
*/     & cfarnr == cfarnr[_n-3] & cfarnr == cfarnr[_n-4] & cfarnr == cfarnr[_n-5] & cfarnr == cfarnr[_n-6] & ind_price_changer[_n-6] == 1 & ind_price_changer ~= .

replace accum_mc_change = d_ln_obs_marginal_cost_is + d_ln_obs_marginal_cost_is[_n-1] + d_ln_obs_marginal_cost_is[_n-2] + d_ln_obs_marginal_cost_is[_n-3] + d_ln_obs_marginal_cost_is[_n-4] + d_ln_obs_marginal_cost_is[_n-5] + d_ln_obs_marginal_cost_is[_n-6]/*
*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & ind_price_changer[_n-5] == 0 & ind_price_changer[_n-6] == 0 & cfarnr == cfarnr[_n-1]  & cfarnr == cfarnr[_n-2] /*
*/     & cfarnr == cfarnr[_n-3] & cfarnr == cfarnr[_n-4] & cfarnr == cfarnr[_n-5] & cfarnr == cfarnr[_n-6] & cfarnr == cfarnr[_n-7] & ind_price_changer[_n-7] == 1 &  ind_price_changer ~= .

replace abs_accum_mc_change = abs(accum_mc_change)  

summarize ind_price_changer abs_accum_mc_change accum_mc_change if abs_accum_mc_change~=.

reg ind_price_changer abs_accum_mc_change, cluster(cfarnr)

lpoly ind_price_changer abs_accum_mc_change if abs_accum_mc_change<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(0(0.1)0.3) xtick(0(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Abs. Acc. Log Unit Labor Cost Change - Zero Bin)  n(12)  /*
*/ name(smoother_abs_accum_change_zero, replace) title("") nolegend note("") scheme(s2mono)

lpoly ind_price_changer accum_mc_change if abs_accum_mc_change<=0.3, /*
*/ noscatter ci ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(-0.3(0.1)0.3) xtick(-0.3(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Acc. Log Unit Labor Cost Change - Zero Bin)  n(24)  /*
*/ name(smoother_accum_change_zero, replace) title("") nolegend note("") scheme(s2mono)

graph set ps logo off
graph combine smoother_abs_accum_change_base_2 smoother_accum_change_base smoother_abs_accum_change_zero smoother_accum_change_zero, cols(2)  ycommon name(smoother_fig_rob)
graph save smoother_fig_rob "C:\results\smoother_fig_rob.gph", replace
graph export "C:\results\smoother_fig_rob.ps", replace

graph drop smoother_accum_change_base smoother_abs_accum_change_zero smoother_accum_change_zero smoother_abs_accum_change_base_2

**************************
* Simulated Data Menu Cost
**************************

matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
		
	gen accum_mc_change = .
	replace accum_mc_change = d_ln_marginal_cost_sim if ind_price_changer[_n-1] == 1 & plant_good_marker == plant_good_marker[_n-1] & ind_price_changer ~= . 

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] /*
	*/     if ind_price_changer[_n-1] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & plant_good_marker == plant_good_marker[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3] + d_ln_marginal_cost_sim[_n-4]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .

		
	qui: gen  abs_accum_mc_change = abs(accum_mc_change) 
	
	* Save data for figure 
	qui: save "C:\sim_data\MCM_sim_dat_adj_`i'.dta", replace
		
	* Column 1
	qui: reg ind_price_changer abs_accum_mc_change
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	
	* Column 2
	* Probit
	qui: dprobit ind_price_changer  abs_accum_mc_change
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',2] = est_prob_margin[1,1]
		
	* Column 3
	* Logit 
	qui: logit ind_price_changer abs_accum_mc_change
	qui: margins, dydx(abs_accum_mc_change) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',3] = est_logit_margin[1,1]
	
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0 & d_ln_price_sim ~= .
	
	qui: replace accum_mc_change = .
	qui: replace accum_mc_change = d_ln_marginal_cost_sim if ind_price_changer[_n-1] == 1 & plant_good_marker == plant_good_marker[_n-1] & ind_price_changer ~= . 

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] /*
	*/     if ind_price_changer[_n-1] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & plant_good_marker == plant_good_marker[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3] + d_ln_marginal_cost_sim[_n-4]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .
	
	qui: replace abs_accum_mc_change = abs(accum_mc_change) 
	
	* Column 4
	qui: reg ind_price_changer abs_accum_mc_change
	qui: mat est_ols = e(b)
	qui: mat results[`i',4] = est_ols[1,1]

		
	* Column 5
	* Probit
	qui: dprobit ind_price_changer  abs_accum_mc_change
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',5] = est_prob_margin[1,1]
		
	* Column 6
	* Logit 
	qui: logit ind_price_changer abs_accum_mc_change
	qui: margins, dydx(abs_accum_mc_change) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',6] = est_logit_margin[1,1]
	
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_true_selection_mc_accum.dta", replace

* Figure 
use "C:\sim_data\MCM_sim_dat_adj_1.dta", clear
forvalues i = 2/200 {
	append using "C:\sim_data\MCM_sim_dat_adj_`i'.dta"
} 

lpoly ind_price_changer abs_accum_mc_change if abs_accum_mc_change<=0.3, /*
*/ ci noscatter ylabel(0.8(0.1)1) ytick(0.8(0.1)1)  xlabel(0(0.1)0.3) xtick(0(0.1)0.3) /*
*/ ytitle(Price Change Probability) xtitle(Abs. Acc. Log Unit Labor Cost Change - Simulation)  n(12)  /*
*/ name(smoother_abs_accum_change_sim_mc, replace) title("") nolegend note("") scheme(s2mono)

graph set ps logo off
graph combine  smoother_abs_accum_change_base smoother_abs_accum_change_sim_mc, scheme(s2mono) ycommon xcommon name(smoother_fig1, replace)
graph save smoother_fig1 "C:\results\smoother_fig1.gph", replace
graph export "C:\results\smoother_fig1.ps", replace

graph drop  smoother_abs_accum_change_base smoother_abs_accum_change_sim_mc

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_alt_measures_menu_cost.dta", replace
clear  



************
* Calvo Plus
************

matrix drop _all
forvalues i = 1/200 {
	mat results = (nullmat(results)\(0,0,0,0,0,0))
} 

* Main Loop 
forvalues i = 1/200 {
	* disp `i'
	* Read Simulated Data from Matlab
	qui: infile plant_good_marker aar ln_price_sim ln_marginal_cost_sim using /*
	*/ "C:\sim_data\MCM_sim_dat_calvo_plus_`i'.raw", clear

	qui: xtset plant_good_marker aar
	qui: sort plant_good_marker aar

	* Transformations for probability regressions
	qui: gen  d_ln_price_sim  =  ln_price_sim - l.ln_price_sim

	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0.005 & d_ln_price_sim ~= .
	
	qui: gen  d_ln_marginal_cost_sim = ln_marginal_cost_sim - l.ln_marginal_cost_sim
		
	gen accum_mc_change = .
	replace accum_mc_change = d_ln_marginal_cost_sim if ind_price_changer[_n-1] == 1 & plant_good_marker == plant_good_marker[_n-1] & ind_price_changer ~= . 

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] /*
	*/     if ind_price_changer[_n-1] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & plant_good_marker == plant_good_marker[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

	replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3] + d_ln_marginal_cost_sim[_n-4]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .

		
	qui: gen  abs_accum_mc_change = abs(accum_mc_change) 
	
	
	* Column 1
	qui: reg ind_price_changer abs_accum_mc_change
	qui: mat est_ols = e(b)
	qui: mat results[`i',1] = est_ols[1,1]
	
	* Column 2
	* Probit
	qui: dprobit ind_price_changer  abs_accum_mc_change
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',2] = est_prob_margin[1,1]
		
	* Column 3
	* Logit 
	qui: logit ind_price_changer abs_accum_mc_change
	qui: margins, dydx(abs_accum_mc_change) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',3] = est_logit_margin[1,1]
	
	
	qui: drop ind_price_changer
	
	qui: gen ind_price_changer = 0 if d_ln_price_sim ~= .
	qui: replace ind_price_changer = 1 if abs(d_ln_price_sim)>0 & d_ln_price_sim ~= .
	
	qui: replace accum_mc_change = .
	qui: replace accum_mc_change = d_ln_marginal_cost_sim if ind_price_changer[_n-1] == 1 & plant_good_marker == plant_good_marker[_n-1] & ind_price_changer ~= . 

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] /*
	*/     if ind_price_changer[_n-1] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & ind_price_changer[_n-2] == 1 & ind_price_changer ~= .

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & plant_good_marker == plant_good_marker[_n-1] & plant_good_marker == plant_good_marker[_n-2] & plant_good_marker == plant_good_marker[_n-3] & ind_price_changer[_n-3] == 1 & ind_price_changer ~= .

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & ind_price_changer[_n-4] == 1 & ind_price_changer ~= .

	qui: replace accum_mc_change = d_ln_marginal_cost_sim + d_ln_marginal_cost_sim[_n-1] + d_ln_marginal_cost_sim[_n-2] + d_ln_marginal_cost_sim[_n-3] + d_ln_marginal_cost_sim[_n-4]/*
	*/     if ind_price_changer[_n-1] == 0 & ind_price_changer[_n-2] == 0 & ind_price_changer[_n-3] == 0 & ind_price_changer[_n-4] == 0 & plant_good_marker == plant_good_marker[_n-1]  & plant_good_marker == plant_good_marker[_n-2] /*
	*/     & plant_good_marker == plant_good_marker[_n-3] & plant_good_marker == plant_good_marker[_n-4] & plant_good_marker == plant_good_marker[_n-5] & ind_price_changer[_n-5] == 1 & ind_price_changer ~= .
	
	qui: replace abs_accum_mc_change = abs(accum_mc_change) 
	
	* Column 4
	qui: reg ind_price_changer abs_accum_mc_change
	qui: mat est_ols = e(b)
	qui: mat results[`i',4] = est_ols[1,1]

		
	* Column 5
	* Probit
	qui: dprobit ind_price_changer  abs_accum_mc_change
	qui: mat est_prob_margin =  e(dfdx)
    qui: mat results[`i',5] = est_prob_margin[1,1]
		
	* Column 6
	* Logit 
	qui: logit ind_price_changer abs_accum_mc_change
	qui: margins, dydx(abs_accum_mc_change) atmeans
    qui: mat est_logit_margin =  r(b) 
    qui: mat results[`i',6] = est_logit_margin[1,1]
	
}

clear  
svmat results 
summarize 
save "C:\sim_data\Sim_estimates_true_selection_cp_accum.dta", replace


****************

log close
